/*
    GNOME Commander - A GNOME based file manager
    Copyright (C) 2001-2006 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef __LIBGCMD_H__
#define __LIBGCMD_H__

#include <libgcmd/libgcmd-deps.h>
#include <libgcmd/libgcmd-utils.h>
#include <libgcmd/libgcmd-data.h>
#include <libgcmd/libgcmd-widget-factory.h>
#include <libgcmd/gnome-cmd-state.h>
#include <libgcmd/gnome-cmd-plugin.h>
#include <libgcmd/gnome-cmd-file-info.h>
#include <libgcmd/gnome-cmd-dialog.h>
#include <libgcmd/gnome-cmd-string-dialog.h>
#include <libgcmd/plugin-info.h>

G_BEGIN_DECLS
G_END_DECLS

#endif //__LIBGCMD_H__
